==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/CSISnapshotControllerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSISnapshotControllerListBuilder extends io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList,io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListBuilder>{
  public CSISnapshotControllerListBuilder() {
    this(false);
  }
  public CSISnapshotControllerListBuilder(java.lang.Boolean validationEnabled) {
    this(new CSISnapshotControllerList(), validationEnabled);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent) {
    this(fluent, false);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSISnapshotControllerList(), validationEnabled);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList instance) {
    this(fluent, instance, false);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList instance) {
    this(instance,false);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList build() {
    CSISnapshotControllerList buildable = new CSISnapshotControllerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSISnapshotControllerListBuilder that = (CSISnapshotControllerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/CSISnapshotControllerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSISnapshotControllerListBuilder extends io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList,io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListBuilder>{
  public CSISnapshotControllerListBuilder() {
    this(false);
  }
  public CSISnapshotControllerListBuilder(java.lang.Boolean validationEnabled) {
    this(new CSISnapshotControllerList(), validationEnabled);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent) {
    this(fluent, false);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSISnapshotControllerList(), validationEnabled);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList instance) {
    this(fluent, instance, false);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList instance) {
    this(instance,false);
  }
  public CSISnapshotControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.CSISnapshotControllerList build() {
    CSISnapshotControllerList buildable = new CSISnapshotControllerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSISnapshotControllerListBuilder that = (CSISnapshotControllerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
